@@ -1,8 +1,16 @@
-#' @title Read ARFF file
+#' @title Read ARFF files
 #'
 #' @description
 #' Parses a file located at `path` and returns a [data.table()].
 #'
+#' Limitations:
+#'
+#' * Only works for dense files, no support for sparse data.
+#'   Use \CRANpkg{RWeka} instead.
+#' * Dates (even if there is no time component) are read in as [POSIXct].
+#' * The `date-format` from the ARFF specification is currently ignored.
+#'   Instead, we rely on the auto-detection of \CRANpkg{data.table}'s [fread()]..
+#'
 #' @param path (`character(1)`)\cr
 #'   Path or URI of the ARFF file, passed to [file()].
 #'
@@ -24,9 +32,10 @@ read_arff = function(path) {
     # this prevents double unquoting;
     # lines already unquoted w.r.t ' do not get unquote w.r.t. " again
     i = FALSE
+    not_na = !is.na(x)
 
     for (quote in c("'", "\"")) {
-      i = !i & !is.na(x) & stri_startswith_fixed(x, quote) & stri_endswith_fixed(x, quote)
+      i = !i & not_na & stri_startswith_fixed(x, quote) & stri_endswith_fixed(x, quote)
       x[i] = stri_sub(x[i], 2L, -2L)
     }
     x
@@ -65,12 +74,17 @@ read_arff = function(path) {
   # extract and translate col classes
   col_classes = declarations[, 3L]
   is_factor = stri_startswith_fixed(col_classes, "{")
+  is_date = grepl("^date", col_classes, ignore.case = TRUE)
   lvls = set_names(lapply(col_classes[is_factor], parse_arff_levels), col_names[is_factor])
-  col_classes = ifelse(is_factor, "character", tolower(col_classes))
+
+  ii = !is_factor & !is_date
+  col_classes[ii] = tolower(col_classes[ii])
+  col_classes[is_factor] = "character"
+  col_classes[is_date] = "date"
 
   mapped_col_classes = map_values(col_classes,
-    old = c("integer", "real",    "numeric", "string",    "date"),
-    new = c(NA,        NA,        NA,        "character", "character")
+    old = c("integer", "real", "numeric", "string", "date"),
+    new = c(NA, NA, NA, "character", "POSIXct")
   )
 
   # read data in chunks with workaround for missing comment char functionality
@@ -82,9 +96,11 @@ read_arff = function(path) {
   counter = 1L
 
   while (length(lines) > 0L) {
-    tmp = try(fread(text = lines, col.names = col_names,
+    tmp = try(fread(
+      text = lines, col.names = col_names,
       sep = ",", quote = quote_char, na.strings = "?", blank.lines.skip = TRUE,
-      header = FALSE, colClasses = mapped_col_classes), silent = TRUE)
+      header = FALSE, colClasses = mapped_col_classes
+    ), silent = TRUE)
 
     if (inherits(tmp, "try-error")) {
       if (quote_char != "'") {
